@@ -424,14 +424,10 @@ def is_slashable_attestation_data(data_1: AttestationData, data_2: AttestationDa
 
 def is_valid_indexed_attestation(state: BeaconState, indexed_attestation: IndexedAttestation) -> bool:
     """
-    Check if ``indexed_attestation`` has valid indices and signature.
+    Check if ``indexed_attestation`` has sorted and unique indices and a valid aggregate signature.
     """
-    indices = indexed_attestation.attesting_indices
-
-    # Verify max number of indices
-    if not len(indices) <= MAX_VALIDATORS_PER_COMMITTEE:
-        return False
     # Verify indices are sorted and unique
+    indices = indexed_attestation.attesting_indices
     if not indices == sorted(set(indices)):
         return False
     # Verify aggregate signature
@@ -1286,7 +1282,7 @@ def get_forkchoice_store(anchor_state: BeaconState) -> Store:
     justified_checkpoint = Checkpoint(epoch=anchor_epoch, root=anchor_root)
     finalized_checkpoint = Checkpoint(epoch=anchor_epoch, root=anchor_root)
     return Store(
-        time=anchor_state.genesis_time,
+        time=anchor_state.genesis_time + SECONDS_PER_SLOT * anchor_state.slot,
         genesis_time=anchor_state.genesis_time,
         justified_checkpoint=justified_checkpoint,
         finalized_checkpoint=finalized_checkpoint,
